<?php

namespace Asadi\Standard\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Asadi\Standard\Interfaces\StandardRepositoryInterface;
use Asadi\Standard\Repositories\Presenter\StandardItemTransformer;

/**
 * Pubic API controller class.
 */
class StandardPublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Asadi\Standard\Interfaces\StandardRepositoryInterface $standard
     *
     * @return type
     */
    public function __construct(StandardRepositoryInterface $standard)
    {
        $this->repository = $standard;
        parent::__construct();
    }

    /**
     * Show standard's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $standards = $this->repository
            ->setPresenter('\\Asadi\\Standard\\Repositories\\Presenter\\StandardListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $standards['code'] = 2000;
        return response()->json($standards)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show standard.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $standard = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($standard)) {
            $standard         = $this->itemPresenter($module, new StandardItemTransformer);
            $standard['code'] = 2001;
            return response()->json($standard)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
