<?php

namespace Asadi\Standard\Http\Controllers;
use Litepie\Standard\Http\Requests\StandardRequest;
use Litepie\Standard\Models\Standard;

trait StandardWorkflow {
	
    /**
     * Workflow controller function for standard.
     *
     * @param Model   $standard
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(StandardRequest $request, Standard $standard, $step)
    {

        try {

            $standard->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('standard::standard.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/standard/standard/' . $standard->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/standard/standard/' . $standard->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for standard.
     *
     * @param Model   $standard
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Standard $standard, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $standard->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('standard::standard.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('standard::admin.standard.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('standard::admin.standard.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('standard::admin.standard.message', $data)->render();

        }

    }
}