<?php

namespace Asadi\Standard\Policies;

use App\User;
use Asadi\Standard\Models\Standard;

class StandardPolicy
{

    /**
     * Determine if the given user can view the standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function view(User $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $standard->user_id;
    }

    /**
     * Determine if the given user can create a standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('standard.standard.create');
    }

    /**
     * Determine if the given user can update the given standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function update(User $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $standard->user_id;
    }

    /**
     * Determine if the given user can delete the given standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function destroy(User $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $standard->user_id;
    }

    /**
     * Determine if the given user can verify the given standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function verify(User $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('standard.standard.verify') 
        && $user->is('manager')
        && $standard->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given standard.
     *
     * @param User $user
     * @param Standard $standard
     *
     * @return bool
     */
    public function approve(User $user, Standard $standard)
    {
        if ($user->canDo('standard.standard.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
