<?php

namespace Asadi\Standard\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Asadi\Standard\Models\Standard;

class StandardAction
{
    /**
     * Perform the complete action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */
    public function complete(Standard $standard)
    {
        try {
            $standard->status = 'complete';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */public function verify(Standard $standard)
    {
        try {
            $standard->status = 'verify';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */public function approve(Standard $standard)
    {
        try {
            $standard->status = 'approve';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */public function publish(Standard $standard)
    {
        try {
            $standard->status = 'publish';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */
    public function archive(Standard $standard)
    {
        try {
            $standard->status = 'archive';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Standard $standard
     *
     * @return Standard
     */
    public function unpublish(Standard $standard)
    {
        try {
            $standard->status = 'unpublish';
            return $standard->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
