<?php

namespace Asadi\Standard\Workflow;

use Asadi\Standard\Models\Standard;
use Validator;

class StandardValidator
{

    /**
     * Determine if the given standard is valid for complete status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function complete(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given standard is valid for verify status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function verify(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given standard is valid for approve status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function approve(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given standard is valid for publish status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function publish(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given standard is valid for archive status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function archive(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given standard is valid for unpublish status.
     *
     * @param Standard $standard
     *
     * @return bool / Validator
     */
    public function unpublish(Standard $standard)
    {
        return Validator::make($standard->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
